# -*- encoding:utf-8 -*-
from __future__ import unicode_literals

MESSAGES = {
    "%d min remaining to read": "%d min zbývajících",
    "(active)": "",
    "Also available in:": "Dostupné také v",
    "Archive": "Archiv",
    "Categories": "Kategorie",
    "Comments": "Komentáře",
    "LANGUAGE": "Čeština",
    "Languages:": "Jazyky:",
    "More posts about %s": "Další příspěvky o %s",
    "Newer posts": "Novější příspěvky",
    "Next post": "Další příspěvek",
    "No posts found.": "Nebyly nalezeny žádné příspěvky.",
    "Nothing found.": "Nic nebylo nalezeno.",
    "Older posts": "Starší příspěvky",
    "Original site": "Původní stránka",
    "Posted:": "Zveřejněno:",
    "Posts about %s": "Příspěvky o %s",
    "Posts for year %s": "Příspěvky v roce %s",
    "Posts for {month} {day}, {year}": "Příspěvky v {month} {day}, {year}",
    "Posts for {month} {year}": "Příspěvky v {month} {year}",
    "Previous post": "Předchozí příspěvek",
    "Publication date": "Datum zveřejnění",
    "RSS feed": "RSS zdroj",
    "Read in English": "Číst v češtině",
    "Read more": "Číst dál",
    "Skip to main content": "Přeskočit na hlavní obsah",
    "Source": "Zdroj",
    "Subcategories:": "",
    "Tags and Categories": "Štítky a kategorie",
    "Tags": "Štítky",
    "Write your page here.": "",
    "Write your post here.": "",
    "old posts, page %d": "staré příspěvky, strana %d",
    "page %d": "strana %d",
}
