# -*- encoding:utf-8 -*-
from __future__ import unicode_literals

MESSAGES = {
    "%d min remaining to read": "読込むまで残り %d 分",
    "(active)": "",
    "Also available in:": "他の言語で読む：",
    "Archive": "過去の記事",
    "Categories": "カテゴリー",
    "Comments": "コメント",
    "LANGUAGE": "日本語",
    "Languages:": "言語 :",
    "More posts about %s": "タグ： %s",
    "Newer posts": "新しい記事",
    "Next post": "次の記事",
    "No posts found.": "記事はありません",
    "Nothing found.": "なにも見つかりませんでした",
    "Older posts": "過去の記事",
    "Original site": "元のサイト",
    "Posted:": "投稿日時：",
    "Posts about %s": "%sについての記事",
    "Posts for year %s": "%s年の記事",
    "Posts for {month} {day}, {year}": "{year}年{month}月{day}日の記事",
    "Posts for {month} {year}": "{year}年{month}月の記事",
    "Previous post": "前の記事",
    "Publication date": "投稿日",
    "RSS feed": "RSS フィード",
    "Read in English": "日本語で読む",
    "Read more": "続きを読む",
    "Skip to main content": "メインコンテンツをスキップ",
    "Source": "ソース",
    "Subcategories:": "",
    "Tags and Categories": "タグとカテゴリー",
    "Tags": "タグ",
    "Write your page here.": "",
    "Write your post here.": "",
    "old posts, page %d": "前の記事 %dページ目",
    "page %d": "ページ %d",
}
