# -*- encoding:utf-8 -*-
from __future__ import unicode_literals

MESSAGES = {
    "%d min remaining to read": "%d min remaining to read",
    "(active)": "(active)",
    "Also available in:": "Also available in:",
    "Archive": "Archive",
    "Categories": "Categories",
    "Comments": "Comments",
    "LANGUAGE": "English",
    "Languages:": "Languages:",
    "More posts about %s": "More posts about %s",
    "Newer posts": "Newer posts",
    "Next post": "Next post",
    "No posts found.": "No posts found.",
    "Nothing found.": "Nothing found.",
    "Older posts": "Older posts",
    "Original site": "Original site",
    "Posted:": "Posted:",
    "Posts about %s": "Posts about %s",
    "Posts for year %s": "Posts for year %s",
    "Posts for {month} {day}, {year}": "Posts for {month} {day}, {year}",
    "Posts for {month} {year}": "Posts for {month} {year}",
    "Previous post": "Previous post",
    "Publication date": "Publication date",
    "RSS feed": "RSS feed",
    "Read in English": "Read in English",
    "Read more": "Read more",
    "Skip to main content": "Skip to main content",
    "Source": "Source",
    "Subcategories:": "Subcategories:",
    "Tags and Categories": "Tags and Categories",
    "Tags": "Tags",
    "Write your page here.": "Write your page here.",
    "Write your post here.": "Write your post here.",
    "old posts, page %d": "old posts, page %d",
    "page %d": "page %d",
}
