# -*- encoding:utf-8 -*-
from __future__ import unicode_literals

MESSAGES = {
    "%d min remaining to read": "%d minutos restante para leitura",
    "(active)": "(ativo)",
    "Also available in:": "Também disponível em:",
    "Archive": "Arquivo",
    "Categories": "Categorias",
    "Comments": "Comentários",
    "LANGUAGE": "Português",
    "Languages:": "Idiomas:",
    "More posts about %s": "Mais textos publicados sobre %s",
    "Newer posts": "Textos publicados mais recentes",
    "Next post": "Próximo texto publicado",
    "No posts found.": "Nenhum texto publicado foi encontrado",
    "Nothing found.": "Nada encontrado.",
    "Older posts": "Textos publicados mais antigos",
    "Original site": "Sítio original",
    "Posted:": "Publicado:",
    "Posts about %s": "Textos publicados sobre %s",
    "Posts for year %s": "Textos publicados do ano %s",
    "Posts for {month} {day}, {year}": "Textos publicados de {day} {month} {year}",
    "Posts for {month} {year}": "Textos publicados de {month} {year}",
    "Previous post": "Texto publicado anterior",
    "Publication date": "Data de publicação",
    "RSS feed": "Feed RSS",
    "Read in English": "Ler em português",
    "Read more": "Ler mais",
    "Skip to main content": "Saltar para o conteúdo principal",
    "Source": "Código",
    "Subcategories:": "Sub-Categorias:",
    "Tags and Categories": "Etiquetas e Categorias",
    "Tags": "Etiqueta",
    "Write your page here.": "Escreva a sua página aqui.",
    "Write your post here.": "Escreva o seu texto para publicar aqui.",
    "old posts, page %d": "Textos publicados antigos, página %d",
    "page %d": "página %d",
}
