/*
	jQuery Colorbox language configuration
	language: Indonesian (id)
	translated by: sarwasunda
*/
jQuery.extend(jQuery.colorbox.settings, {
	current: "ke {current} dari {total}",
	previous: "Sebelumnya",
	next: "Berikutnya",
	close: "Tutup",
	xhrError: "Konten ini tidak dapat dimuat.",
	imgError: "Gambar ini tidak dapat dimuat.",
	slideshowStart: "Putar",
	slideshowStop: "Berhenti"
});
