# -*- encoding:utf-8 -*-
from __future__ import unicode_literals

MESSAGES = {
    "%d min remaining to read": "",
    "(active)": "",
    "Also available in:": "أيضا متوفر في:",
    "Archive": "الأرشيف",
    "Categories": "فئات",
    "Comments": "التّعليقات",
    "LANGUAGE": "العربيّة",
    "Languages:": "اللغات",
    "More posts about %s": "المزيد من المقالات حول %s",
    "Newer posts": "مقالات أحدث",
    "Next post": "المقالة التالية",
    "No posts found.": "لم يوجد مقالات.",
    "Nothing found.": "لم يوجد شيء.",
    "Older posts": "مقالات أقدم",
    "Original site": "الموقع الأصلي",
    "Posted:": "نشر:",
    "Posts about %s": "مقالات عن s%",
    "Posts for year %s": "مقالات سنة s%",
    "Posts for {month} {day}, {year}": "",
    "Posts for {month} {year}": "",
    "Previous post": "المقالة السابقة",
    "Publication date": "تاريخ النشر",
    "RSS feed": "",
    "Read in English": "اقرأ بالعربية",
    "Read more": "قراءة المزيد",
    "Skip to main content": "انتقل إلى المحتوى الرئيسي",
    "Source": "المصدر",
    "Subcategories:": "",
    "Tags and Categories": "تصنيفات و فئات",
    "Tags": "تصنيفات",
    "Write your page here.": "",
    "Write your post here.": "",
    "old posts, page %d": "مقالات قديمة, صفحة d%",
    "page %d": "صفحة d%",
}
