/*
  jQuery Colorbox language configuration
	language: Bulgarian (bg)
	translated by: Marian M.Bida
	site: webmax.bg
*/
jQuery.extend(jQuery.colorbox.settings, {
	current: "изображение {current} от {total}",
	previous: "предишна",
	next: "следваща",
	close: "затвори",
	xhrError: "Неуспешно зареждане на съдържанието.",
	imgError: "Неуспешно зареждане на изображението.",
	slideshowStart: "пусни слайд-шоу",
	slideshowStop: "спри слайд-шоу"
});
