/*
    jQuery ColorBox language configuration
    language: Ukrainian (uk)
    translated by: Andrew
    http://acisoftware.com.ua
*/
jQuery.extend(jQuery.colorbox.settings, {
    current: "зображення {current} з {total}",
    previous: "попереднє",
    next: "наступне",
    close: "закрити",
    xhrError: "Не вдалося завантажити вміст.",
    imgError: "Не вдалося завантажити зображення.",
    slideshowStart: "почати слайд-шоу",
    slideshowStop: "зупинити слайд-шоу"
});