# -*- encoding:utf-8 -*-
from __future__ import unicode_literals

MESSAGES = {
    "%d min remaining to read": "ਪੜਣ ਲਈ  %d ਮਿੰਟ ਬਾਕੀ",
    "(active)": "(ਚਲੰਤ)",
    "Also available in:": "ਹੋਰ  ਉਪਲਬਧ ਬੋਲੀਆਂ:",
    "Archive": "ਆਰਕਾਈਵ",
    "Categories": "ਸ਼੍ਰੇਣੀ",
    "Comments": "ਟਿੱਪਣੀਆਂ",
    "LANGUAGE": "ਅੰਗਰੇਜ਼ੀ",
    "Languages:": "ਬੋਲੀਆਂ:",
    "More posts about %s": "%s ਬਾਰੇ ਹੋਰ ਲਿਖਤਾਂ",
    "Newer posts": "ਨਵੀਆਂ ਲਿਖਤਾਂ",
    "Next post": "ਅਗਲੀ ਲਿਖਤ",
    "No posts found.": "ਕੋਈ ਲਿਖਤ ਨਹੀਂ ਲੱਭੀ |",
    "Nothing found.": "ਕੁਝ ਨਹੀਂ ਲੱਭਿਆ |",
    "Older posts": "ਪੁਰਾਣੀਆਂ ਲਿਖਤਾਂ",
    "Original site": "ਅਸਲ ਸਾਈਟ",
    "Posted:": "ਲਿਖਤ ਛਪੀ:",
    "Posts about %s": "%s ਬਾਰੇ ਲਿਖਤਾਂ",
    "Posts for year %s": "ਸਾਲ %s ਦੀਆਂ ਲਿਖਤਾਂ",
    "Posts for {month} {day}, {year}": "{day} {month} {year} ਦੀਆਂ ਲਿਖਤਾਂ",
    "Posts for {month} {year}": "{month} {year} ਦੀਆਂ ਲਿਖਤਾਂ",
    "Previous post": "ਪਿਛਲੀ ਲਿਖਤ",
    "Publication date": "ਛਪਾਈ ਦੀ ਤਰੀਕ",
    "RSS feed": "ਆਰ ਐੱਸ ਐੱਸ ਫੀਡ",
    "Read in English": "ਅੰਗਰੇਜ਼ੀ ਵਿੱਚ ਪੜ੍ਹੋ",
    "Read more": "ਹੋਰ ਪੜ੍ਹੋ",
    "Skip to main content": "ਮੁੱਖ ਸਮੱਗਰੀ ਵੱਲ ਜਾਓ",
    "Source": "ਮੂਲ",
    "Subcategories:": "ਉਪਸ਼੍ਰੇਣੀਆਂ:",
    "Tags and Categories": "ਟੈਗ ਅਤੇ ਸ਼੍ਰੇਣੀਆਂ",
    "Tags": "ਟੈਗ",
    "Write your page here.": "ਆਪਣਾ ਸਫ਼ਾ ਏਥੇ ਲਿਖੋ |",
    "Write your post here.": "ਆਪਣੀ ਲਿਖਤ ਏਥੇ ਲਿਖੋ |",
    "old posts, page %d": "ਪੁਰਾਣੀਆਂ ਲਿਖਤਾਂ , ਸਫ਼ਾ %d",
    "page %d": "ਸਫ਼ਾ %d",
}
