# -*- encoding:utf-8 -*-
from __future__ import unicode_literals

MESSAGES = {
    "%d min remaining to read": "",
    "(active)": "",
    "Also available in:": "Ankaŭ disponebla en:",
    "Archive": "Arĥivo",
    "Categories": "Kategorioj",
    "Comments": "",
    "LANGUAGE": "Anglalingve",
    "Languages:": "",
    "More posts about %s": "Pli artikoloj pri %s",
    "Newer posts": "Pli novaj artikoloj",
    "Next post": "Venonta artikolo",
    "No posts found.": "",
    "Nothing found.": "",
    "Older posts": "Pli malnovaj artikoloj",
    "Original site": "Originala interretejo",
    "Posted:": "Skribita:",
    "Posts about %s": "Artikoloj pri %s",
    "Posts for year %s": "Artikoloj de la jaro %s",
    "Posts for {month} {day}, {year}": "",
    "Posts for {month} {year}": "Artikoloj skribitaj en {month} {year}",
    "Previous post": "Antaŭa artikolo",
    "Publication date": "",
    "RSS feed": "",
    "Read in English": "Legu ĝin en Esperanto",
    "Read more": "Legu plu",
    "Skip to main content": "",
    "Source": "Fonto",
    "Subcategories:": "",
    "Tags and Categories": "Etikedoj kaj Kategorioj",
    "Tags": "Etikedoj",
    "Write your page here.": "",
    "Write your post here.": "",
    "old posts, page %d": "paĝo de malnovaj artikoloj %d",
    "page %d": "paĝo %d",
}
