/*
	jQuery Colorbox language configuration
	language: Norwegian (no)
	translated by: lars-erik
	site: markedspartner.no
*/
jQuery.extend(jQuery.colorbox.settings, {
	current: "Bilde {current} av {total}",
	previous: "Forrige",
	next: "Neste",
	close: "Lukk",
	xhrError: "Feil ved lasting av innhold.",
	imgError: "Feil ved lasting av bilde.",
	slideshowStart: "Start lysbildefremvisning",
	slideshowStop: "Stopp lysbildefremvisning"
});
