# -*- encoding:utf-8 -*-
from __future__ import unicode_literals

MESSAGES = {
    "%d min remaining to read": "Залишилось читати %d хвилин",
    "(active)": "",
    "Also available in:": "Іншою мовою:",
    "Archive": "Архів",
    "Categories": "Категорії",
    "Comments": "Коментарі",
    "LANGUAGE": "Українська",
    "Languages:": "Мови:",
    "More posts about %s": "Більше статей про  %s",
    "Newer posts": "Нові статті",
    "Next post": "Наступна стаття",
    "No posts found.": "Не знайдено жодної статті",
    "Nothing found.": "Нічого не знайдено",
    "Older posts": "Більш старі статті",
    "Original site": "Оригінал сайту",
    "Posted:": "Опублікована:",
    "Posts about %s": "Статті про %s",
    "Posts for year %s": "Статті за %s рік",
    "Posts for {month} {day}, {year}": "Статті за {month} {day}, {year}",
    "Posts for {month} {year}": "Статті за {month} {year}",
    "Previous post": "Попередня стаття",
    "Publication date": "Дата публікації",
    "RSS feed": "RSS-стрічка",
    "Read in English": "Читати українською",
    "Read more": "Читати далі",
    "Skip to main content": "Перейти до основного матеріалу",
    "Source": "Джерело",
    "Subcategories:": "",
    "Tags and Categories": "Теги і категорії",
    "Tags": "Теги",
    "Write your page here.": "",
    "Write your post here.": "",
    "old posts, page %d": "старі статті, сторінка %d",
    "page %d": "сторінка %d",
}
