# -*- encoding:utf-8 -*-
from __future__ import unicode_literals

MESSAGES = {
    "%d min remaining to read": "% min recordar per a llegir",
    "(active)": "",
    "Also available in:": "També disponibles en:",
    "Archive": "Arxiu",
    "Categories": "Categories",
    "Comments": "Comentaris",
    "LANGUAGE": "Català",
    "Languages:": "Llenguatges:",
    "More posts about %s": "Més entrades sobre %s",
    "Newer posts": "Entrades posteriors",
    "Next post": "Entrada següent",
    "No posts found.": "Publicació no trobada",
    "Nothing found.": "No trobat",
    "Older posts": "Entrades anteriors",
    "Original site": "Lloc original",
    "Posted:": "Publicat:",
    "Posts about %s": "Entrades sobre %s",
    "Posts for year %s": "Entrades de l'any %s",
    "Posts for {month} {day}, {year}": "",
    "Posts for {month} {year}": "Publicat en {month} {year}",
    "Previous post": "Entrada anterior",
    "Publication date": "Data de publicació",
    "RSS feed": "Feed RSS",
    "Read in English": "Llegeix-ho en català",
    "Read more": "Llegeix-ne més",
    "Skip to main content": "Vés al comentari principal",
    "Source": "Codi",
    "Subcategories:": "",
    "Tags and Categories": "Etiquetes i Categories",
    "Tags": "Etiquetes",
    "Write your page here.": "",
    "Write your post here.": "",
    "old posts, page %d": "entrades antigues, pàgina %d",
    "page %d": "pàgina %d",
}
