# -*- encoding:utf-8 -*-
from __future__ import unicode_literals

MESSAGES = {
    "%d min remaining to read": "%d minuuttia lukuaikaa",
    "(active)": "(aktiivinen)",
    "Also available in:": "Saatavilla myös:",
    "Archive": "Arkisto",
    "Categories": "Kategoriat",
    "Comments": "Kommentit",
    "LANGUAGE": "Suomi",
    "Languages:": "Kielet:",
    "More posts about %s": "Lisää postauksia aiheesta %s",
    "Newer posts": "Uudempia postauksia",
    "Next post": "Seuraava postaus",
    "No posts found.": "Postauksia ei löytynyt.",
    "Nothing found.": "Ei hakutuloksia.",
    "Older posts": "Vanhempia postauksia",
    "Original site": "Alkuperäinen sivusto",
    "Posted:": "Postattu:",
    "Posts about %s": "Postauksia aiheesta %s",
    "Posts for year %s": "Postauksia vuodelta %s",
    "Posts for {month} {day}, {year}": "",
    "Posts for {month} {year}": "Postauksia ajalle {month} {year}",
    "Previous post": "Edellinen postaus",
    "Publication date": "Julkaisupäivämäärä",
    "RSS feed": "RSS-syöte",
    "Read in English": "Lue suomeksi",
    "Read more": "Lue lisää",
    "Skip to main content": "Hyppää sisältöön",
    "Source": "Lähde",
    "Subcategories:": "Alakategoriat:",
    "Tags and Categories": "Tagit ja kategoriat",
    "Tags": "Tagit",
    "Write your page here.": "",
    "Write your post here.": "",
    "old posts, page %d": "vanhoja postauksia, sivu %d",
    "page %d": "sivu %d",
}
