// Side effect imports
import './prototype';

import { createDuration } from './create';
import { isDuration } from './constructor';
import { getSetRelativeTimeThreshold } from './humanize';

export {
    createDuration,
    isDuration,
    getSetRelativeTimeThreshold
};
