# -*- encoding:utf-8 -*-
from __future__ import unicode_literals

MESSAGES = {
    "%d min remaining to read": "%d dəqiqəlik oxuma",
    "(active)": "",
    "Also available in:": "Həmçinin mövcuddur:",
    "Archive": "Arxiv",
    "Categories": "Kateqoriyalar",
    "Comments": "Şərhlər",
    "LANGUAGE": "Azərbaycan dili",
    "Languages:": "Dillər:",
    "More posts about %s": "%s ilə bağlı digər yazılar",
    "Newer posts": "Yeni yazılar",
    "Next post": "Növbəti yazı",
    "No posts found.": "Heç bir yazı tapılmadı",
    "Nothing found.": "Heç nə tapılmadı",
    "Older posts": "Köhnə yazılar",
    "Original site": "Original sayt",
    "Posted:": "yazılma tarixi:",
    "Posts about %s": "%s ilə bağlı yazılar",
    "Posts for year %s": "%s ilindəki yazılar",
    "Posts for {month} {day}, {year}": "{month} {day}, {year} üçün yazılar",
    "Posts for {month} {year}": "{month} {year} üçün yazılar",
    "Previous post": "Əvvəlki yazı",
    "Publication date": "Buraxılış tarixi",
    "RSS feed": "RSS",
    "Read in English": "Azərbaycan dilində oxu",
    "Read more": "Davamı",
    "Skip to main content": "Əsas mövzuya keç",
    "Source": "Mənbə",
    "Subcategories:": "",
    "Tags and Categories": "Teqlər və Kateqoriyalar",
    "Tags": "Teqlər",
    "Write your page here.": "",
    "Write your post here.": "",
    "old posts, page %d": "köhnə yazılar, səhifə %s",
    "page %d": "səhifə %d",
}
