/*
	jQuery Colorbox language configuration
	language: Swedish (sv)
	translated by: Mattias Reichel
*/
jQuery.extend(jQuery.colorbox.settings, {
	current: "Bild {current} av {total}",
	previous: "Föregående",
	next: "Nästa",
	close: "Stäng",
	xhrError: "Innehållet kunde inte laddas.",
	imgError: "Den här bilden kunde inte laddas.",
	slideshowStart: "Starta bildspel",
	slideshowStop: "Stoppa bildspel"
});